#!/usr/bin/bash

SESSION_NAME="aide-init"
AIDE_DIR="/var/lib/aide"
DB_FILE="$AIDE_DIR/aide.db.gz"
NEW_DB_FILE="$AIDE_DIR/aide.db.new.gz"
LOG_FILE="$AIDE_DIR/aide-check.log"
TEMP_LOG_FILE="$AIDE_DIR/aide-check-new.log"

FORCE_INIT=0
FORCE_CHECK=0
FORCE_REPORT=0
CHECK_IS_RUNNING=0

# Обработка параметров
case "$1" in
  force-update)
    FORCE_INIT=1
    ;;
  force-check)
    FORCE_CHECK=1
    ;;
  force-report)
    FORCE_REPORT=1
    ;;
  check-is-running)
      CHECK_IS_RUNNING=1
      ;;
esac

# Проверяем, есть ли уже активная screen-сессия
if screen -list | grep -q "\.${SESSION_NAME}[[:space:]]"; then
  echo "Сессия '$SESSION_NAME' уже запущена. Второй запуск не требуется."
  exit 1
fi

# Статус
if [[ CHECK_IS_RUNNING -eq 1 ]]; then
  exit 0
fi

# Проверка времени существующего aide.db.gz
NEED_INIT=0
if [[ $FORCE_INIT -eq 1 ]]; then
  NEED_INIT=1
elif [[ $FORCE_CHECK -eq 1 ]]; then
  NEED_INIT=0
else
  if [[ ! -f "$DB_FILE" ]]; then
    NEED_INIT=1
  else
    # Возраст файла в секундах
    FILE_AGE_SECONDS=$(( $(date +%s) - $(stat -c %Y "$DB_FILE") ))
    if (( FILE_AGE_SECONDS > 10800 )); then # 3 часа
      NEED_INIT=0 #Отключаем обновление, поэтому 0
    fi
  fi
fi

if [[ $FORCE_REPORT -eq 1 ]]; then
  FORCE_INIT=0
  FORCE_CHECK=0
fi

# Проверка лога aide-check
if [[ $FORCE_INIT -eq 0 && $FORCE_CHECK -eq 0 ]]; then
  if [[ -f "$LOG_FILE" ]]; then
    LOG_AGE_SECONDS=$(( $(date +%s) - $(stat -c %Y "$LOG_FILE") ))
    if [[ $FORCE_REPORT -eq 1 ]]; then
      LOG_AGE_SECONDS=0
    fi
    if (( LOG_AGE_SECONDS < 3600 && NEED_INIT == 0 )); then
      #echo "Последний отчёт aide моложе 1 часа:"
      #cat "$LOG_FILE"
      aide-parser "$LOG_FILE"
      exit 0
    fi
  fi
fi

# Теперь запускаем через screen нужную цепочку
if [[ $NEED_INIT -eq 1 ]]; then
  echo "Запускаем AIDE --init и затем --check..."
  screen -dmS "$SESSION_NAME" bash -c "
    shopt -s dotglob &&
    aide --init &&
    mv \"$NEW_DB_FILE\" \"$DB_FILE\" &&
    : > \"$TEMP_LOG_FILE\" 2>&1;
    mv \"$TEMP_LOG_FILE\" \"$LOG_FILE\" &&
    shopt -u dotglob;
    exit
  "
else
  echo "Запускаем только AIDE --check..."
  screen -dmS "$SESSION_NAME" bash -c "
    shopt -s dotglob &&
    aide --check > \"$TEMP_LOG_FILE\" 2>&1;
    mv \"$TEMP_LOG_FILE\" \"$LOG_FILE\" &&
    shopt -u dotglob;
    exit
  "
fi













